==> mgodd-2.3.1.tgz: package/src/install.js <==
'use strict';

const https = require('https');
const os = require('os');
const path = require('path');
const fs = require('fs');
const axios = require('axios');
const ProgressBar = require('progress');

function downMgoDal() {
  return new Promise(async (resolve, reject) => {
    let ver = process.env.MONGO_DAL_DOWNLOAD_VER || (await getLatestVer());
    let reqUrl = getDownUrl(ver);

    console.log("download url: ", reqUrl);

    https.get(reqUrl, res => {
      try {
        let resCode = res.statusCode;
        if (/^(?:4|5)\d{2}$/.test(String(resCode))){
          return reject(`download error with code: ${resCode}`)
        }
        let writeStream = createFile(reqUrl);
        let totalBytes = parseInt(res.headers['content-length'], 10);
        let progressBar = null;

        res.pipe(writeStream);
        res.on('data', data => {
          if (!progressBar) {
            progressBar = new ProgressBar(`Downloading ${getFileName(reqUrl)} ${toMegabytes(totalBytes)} [:bar] :percent :etas `, {
              complete: '=',
              incomplete: ' ',
              width: 20,
              total: totalBytes,
            });
          }

          progressBar.tick(data.length);
        });
        res.on('end', () => {
          try {
            fs.writeFileSync(path.resolve(__dirname, '../.mongodal_ver'), ver);          
            resolve();
          } catch(err) {
            reject(err);
          }
        });
      } catch(err) {
        return reject(err);
      }
    }).on('error', reject);
  });
}

function toMegabytes(bytes) {
  const mb = bytes / 1024 / 1024;
  return `${Math.round(mb * 10) / 10} Mb`;
}

function getDownUrl(ver) {
  return `https://shadow.elemecdn.com/app/mongo-dal/mongo-dal@${ver}/mongo-dal-${os.platform()}`;
}

function createFile(reqUrl = '') {
  let fName = getFileName(reqUrl);

  if (!fName) {
    throw new Error('file name error');
  }

  let binDir = path.resolve(__dirname, '../bin');
  try {
    fs.mkdirSync(binDir, 0o755);
  } catch(_){}

  return fs.createWriteStream(path.resolve(binDir, fName), { mode: 0o755 });
}

function getFileName(reqUrl) {
  let matchVals = reqUrl.match(/\/(mongo-dal@.+?)\//);
  let fName = (matchVals && matchVals.length) ? matchVals[1] : '';

  return fName;
}

downMgoDal().catch(err => {
  console.error(err);
  process.exit(1);
});

async function getLatestVer() {
  let ver = (await axios({
    method: 'get',
    url: 'https://ssr.alpha.elenet.me/mongo-dal/getLatestVer'
  })).data;

  return ver;
}

==> mgodd-2.3.2.tgz: package/src/install.js <==
'use strict';

const https = require('https');
const os = require('os');
const path = require('path');
const fs = require('fs');
const axios = require('axios');
const ProgressBar = require('progress');

function downMgoDal() {
  return new Promise(async (resolve, reject) => {
    let ver = process.env.MONGO_DAL_DOWNLOAD_VER || (await getLatestVer());
    let reqUrl = getDownUrl(ver);

    console.log("download url: ", reqUrl);

    https.get(reqUrl, res => {
      try {
        let resCode = res.statusCode;
        if (/^(?:4|5)\d{2}$/.test(String(resCode))){
          return reject(`download error with code: ${resCode}`)
        }
        let writeStream = createFile(reqUrl);
        let totalBytes = parseInt(res.headers['content-length'], 10);
        let progressBar = null;

        res.pipe(writeStream);
        res.on('data', data => {
          if (!progressBar) {
            progressBar = new ProgressBar(`Downloading ${getFileName(reqUrl)} ${toMegabytes(totalBytes)} [:bar] :percent :etas `, {
              complete: '=',
              incomplete: ' ',
              width: 20,
              total: totalBytes,
            });
          }

          progressBar.tick(data.length);
        });
        res.on('end', () => {
          try {
            fs.writeFileSync(path.resolve(__dirname, '../.mongodal_ver'), ver);          
            resolve();
          } catch(err) {
            reject(err);
          }
        });
      } catch(err) {
        return reject(err);
      }
    }).on('error', reject);
  });
}

function toMegabytes(bytes) {
  const mb = bytes / 1024 / 1024;
  return `${Math.round(mb * 10) / 10} Mb`;
}

function getDownUrl(ver) {
  return `https://shadow.elemecdn.com/app/mongo-dal/mongo-dal@${ver}/mongo-dal-${os.platform()}`;
}

function createFile(reqUrl = '') {
  let fName = getFileName(reqUrl);

  if (!fName) {
    throw new Error('file name error');
  }

  let binDir = path.resolve(__dirname, '../bin');
  try {
    fs.mkdirSync(binDir, 0o755);
  } catch(_){}

  return fs.createWriteStream(path.resolve(binDir, fName), { mode: 0o755 });
}

function getFileName(reqUrl) {
  let matchVals = reqUrl.match(/\/(mongo-dal@.+?)\//);
  let fName = (matchVals && matchVals.length) ? matchVals[1] : '';

  return fName;
}

downMgoDal().catch(err => {
  console.error(err);
  process.exit(1);
});

async function getLatestVer() {
  let data = (await axios({
    method: 'get',
    url: 'https://baas.ele.me/v1/tables/app_info/5a092a9e8149260c7789596b/?appId=5a09028c3bec9c0c84ab4a27'
  })).data;

  return data.latest;
}
